# make sure nbdev_cards package is installed in development mode


<!-- WARNING: THIS FILE WAS AUTOGENERATED! DO NOT EDIT! -->

\# nbdev_cards

> A sample of how to create a deck of cards lib using nbdev

A deck of cards demo of [nbdev](https://nbdev.fast.ai) based on ideas
from [Think Python 2nd
Edition](https://greenteapress.com/wp/think-python-2e/) by Allen B.
Downes

This file will become your README and also the index of your
documentation.

## Developer Guide

If you are new to using `nbdev` here are some useful pointers to get you
started.

### Install

Install using:

    pip install your nbdev_cards

or:

    conda install -c fastai nbdev_cards

### Install nbdev_cards in Development mode

## Usage

### Installation

Install latest from the GitHub
[repository](https://github.com/rdned/nbdev_cards):

``` sh
$ pip install git+https://github.com/rdned/nbdev_cards.git
```

or from [conda](https://anaconda.org/rdned/nbdev_cards)

``` sh
$ conda install -c rdned nbdev_cards
```

or from [pypi](https://pypi.org/project/nbdev_cards/)

``` sh
$ pip install nbdev_cards
```

### Documentation

Documentation can be found hosted on this GitHub
[repository](https://github.com/rdned/nbdev_cards)’s
[pages](https://rdned.github.io/nbdev_cards/). Additionally you can find
package manager specific guidelines on
[conda](https://anaconda.org/rdned/nbdev_cards) and
[pypi](https://pypi.org/project/nbdev_cards/) respectively.

## How to use

This lib provides a
[`Card`](https://rdned.github.io/nbdev_cards/card.html#card) class you
can use to create, display, and compare playing cards:

``` python
suits
```

    ['♣', '♦', '♥', '♠']

``` python
Card(1,3)
```

    3, ♦
